@@ -203,7 +203,8 @@ bool MBox::load(const QString &fileName)
 
     // FIXME: What if unlock fails?
     // if no separator was found, the file is still valid if it is empty
-    return unlock() && ((prevSeparator.size() != 0) || (d->mMboxFile.size() == 0));
+    const bool val = unlock() && (!prevSeparator.isEmpty() || (d->mMboxFile.size() == 0));
+    return val;
 }
 
 bool MBox::lock()
@@ -565,7 +566,7 @@ QByteArray MBox::readMessageHeaders(const MBoxEntry &entry)
 
 bool MBox::save(const QString &fileName)
 {
-    if (!fileName.isEmpty() && QUrl(fileName).toLocalFile() != d->mMboxFile.fileName()) {
+    if (!fileName.isEmpty() && QUrl::fromUserInput(fileName).toLocalFile() != d->mMboxFile.fileName()) {
         if (!d->mMboxFile.copy(fileName)) {
             return false;
         } else {
@@ -610,7 +611,6 @@ bool MBox::save(const QString &fileName)
     d->mMboxFile.write(d->mAppendedEntries);
     d->mAppendedEntries.clear();
     d->mInitialMboxFileSize = d->mMboxFile.size();
-
     return unlock();
 }
 
